package me.hammerle.graphics;

import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JFrame;
import javax.swing.event.MouseInputAdapter;
import me.hammerle.code.Script;

public class GraphicFrame extends JFrame
{
    private final Script parent;
    public final GraphicPanel graphics;
    
    public GraphicFrame(int width, int height, Script sc)
    {
        parent = sc;
        graphics = new GraphicPanel();
        
        super.setSize(width, height + 22);
        super.setResizable(false);
        super.setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        super.setVisible(true);
        super.add(graphics);
        
        super.addWindowListener(new WindowAdapter() 
        {
            @Override
            public void windowClosing(WindowEvent evt) 
            {
                windowClosingEvent(evt);
            }
        });
        
        super.addKeyListener(new KeyAdapter()
        {
            @Override
            public void keyPressed(KeyEvent e) 
            {
                keyEvent(e, "pressed");
            } 
            @Override
            public void keyTyped(KeyEvent e) 
            {
                keyEvent(e, "typed");
            }
            @Override
            public void keyReleased(KeyEvent e) 
            {
                keyEvent(e, "released");
            }
        });
        
        graphics.addMouseListener(new MouseInputAdapter() 
        {
            @Override
            public void mousePressed(MouseEvent e) 
            {
                mouseEvent(e, "pressed");
            }          
        });
    }
    
    private void windowClosingEvent(WindowEvent e)
    {
        if(parent.isLoadedEvent("window-closing"))
        {
            parent.setVar("event", "window-closing");
            parent.runCode(); 
        }
    }
    
    private void keyEvent(KeyEvent e, String name)
    {
        if(parent.isLoadedEvent("key-" + name))
        {
            parent.setVar("event", "key-" + name);
            parent.setVar("keycode", e.getKeyCode());
            parent.setVar("keychar", e.getKeyChar());
            parent.runCode(); 
        }
    }
    
    private void mouseEvent(MouseEvent e, String name)
    {      
        if(parent.isLoadedEvent("mouse-" + name))
        {
            parent.setVar("event", "mouse-" + name);
            parent.setVar("button", e.getButton());
            parent.setVar("count", e.getClickCount());
            parent.setVar("x", e.getX());
            parent.setVar("y", e.getY());
            parent.runCode();  
        }
    }
}
